Coverage report

# Coverage report: 87%

Module | statements | run | excluded | coverage
--- | --- | --- | --- | ---
Total | 1676 | 1466 | 0 | 87%
pages.admin.__init__ | 199 | 168 | 0 | 84%
pages.admin.forms | 63 | 59 | 0 | 94%
pages.admin.utils | 34 | 31 | 0 | 91%
pages.admin.views | 90 | 80 | 0 | 89%
pages.context_processors | 6 | 4 | 0 | 67%
pages.http | 76 | 72 | 0 | 95%
pages.managers | 156 | 152 | 0 | 97%
pages.models | 219 | 187 | 0 | 85%
pages.permissions | 49 | 40 | 0 | 82%
pages.placeholders | 162 | 150 | 0 | 93%
pages.settings | 50 | 45 | 0 | 90%
pages.templatetags.__init__ | 0 | 0 | 0 | 100%
pages.templatetags.pages_tags | 214 | 178 | 0 | 83%
pages.urlconf_registry | 24 | 23 | 0 | 96%
pages.utils | 85 | 79 | 0 | 93%
pages.views | 54 | 50 | 0 | 93%
pages.widgets | 178 | 131 | 0 | 74%
pages.widgets_registry | 17 | 17 | 0 | 100%